@@ -1,6 +1,6 @@
 package Bundle::LWP;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "5.810";
 
 1;
 
@@ -8,7 +8,7 @@ __END__
 
 =head1 NAME
 
-Bundle::LWP - A bundle to install all libwww-perl related modules
+Bundle::LWP - install all libwww-perl related modules
 
 =head1 SYNOPSIS
 
@@ -16,14 +16,14 @@ Bundle::LWP - A bundle to install all libwww-perl related modules
 
 =head1 CONTENTS
 
-URI 1.10           - There are URIs everywhere
-
-Net::FTP 2.00      - If you want ftp://-support
-
 MIME::Base64       - Used in authentication headers
 
 Digest::MD5        - Needed to do Digest authentication
 
+URI 1.10           - There are URIs everywhere
+
+Net::FTP 2.58      - If you want ftp://-support
+
 HTML::Tagset       - Needed by HTML::Parser
 
 HTML::Parser       - Need by HTML::HeadParser
@@ -34,11 +34,10 @@ LWP                - The reason why you need the modules above
 
 =head1 DESCRIPTION
 
-This bundle defines all reqreq modules for libwww-perl.
+This bundle defines all prereq modules for libwww-perl.  Bundles have
+special meaning for the CPAN module.  When you install the bundle
+module all modules mentioned in L</CONTENTS> will be installed instead.
 
+=head1 SEE ALSO
 
-=head1 AUTHOR
-
-Gisle Aas <gisle@aas.no>
-
-=cut
+L<CPAN/Bundles>
