@@ -2,7 +2,6 @@ package LWP::Protocol::http10;
 
 use strict;
 
-require LWP::Debug;
 require HTTP::Response;
 require HTTP::Status;
 require IO::Socket;
@@ -92,7 +91,6 @@ sub _fixup_header
 sub request
 {
     my($self, $request, $proxy, $arg, $size, $timeout) = @_;
-    LWP::Debug::trace('()');
 
     $size ||= 4096;
 
@@ -104,7 +102,7 @@ sub request
 				  "$method for 'http:' URLs";
     }
 
-    my $url = $request->url;
+    my $url = $request->uri;
     my($host, $port, $fullpath);
 
     # Check if we're proxy'ing
@@ -165,7 +163,6 @@ sub request
 	die $! unless defined($n);
 	$offset += $n;
     }
-    LWP::Debug::conns($buf);
 
     if ($ctype eq 'CODE') {
 	while ( ($buf = &$cont_ref()), defined($buf) && length($buf)) {
@@ -178,7 +175,6 @@ sub request
 		die $! unless defined($n);
 		$offset += $n;
 	    }
-	    LWP::Debug::conns($buf);
 	}
     }
     elsif (defined($$cont_ref) && length($$cont_ref)) {
@@ -191,12 +187,9 @@ sub request
 	    die $! unless defined($n);
 	    $offset += $n;
 	}
-	LWP::Debug::conns($$cont_ref);
     }
 
     # read response line from server
-    LWP::Debug::debug('reading response');
-
     my $response;
     $buf = '';
 
@@ -207,13 +200,11 @@ sub request
 	$n = $socket->sysread($buf, $size, length($buf));
 	die $! unless defined($n);
 	die "unexpected EOF before status line seen" unless $n;
-	LWP::Debug::conns($buf);
 
 	if ($buf =~ s/^(HTTP\/\d+\.\d+)[ \t]+(\d+)[ \t]*([^\012]*)\012//) {
 	    # HTTP/1.0 response or better
 	    my($ver,$code,$msg) = ($1, $2, $3);
 	    $msg =~ s/\015$//;
-	    LWP::Debug::debug("$ver $code $msg");
 	    $response = HTTP::Response->new($code, $msg);
 	    $response->protocol($ver);
 
@@ -221,13 +212,11 @@ sub request
 	    # terminated by two blank lines
 	    until ($buf =~ /^\015?\012/ || $buf =~ /\015?\012\015?\012/) {
 		# must read more if we can...
-		LWP::Debug::debug("need more header data");
 		die "read timeout" if $timeout && !$sel->can_read($timeout);
 		my $old_len = length($buf);
 		$n = $socket->sysread($buf, $size, $old_len);
 		die $! unless defined($n);
 		die "unexpected EOF before all headers seen" unless $n;
-		LWP::Debug::conns(substr($buf, $old_len));
 	    }
 
 	    # now we start parsing the headers.  The strategy is to
@@ -262,7 +251,6 @@ sub request
 	elsif ((length($buf) >= 5 and $buf !~ /^HTTP\//) or
 	       $buf =~ /\012/ ) {
 	    # HTTP/0.9 or worse
-	    LWP::Debug::debug("HTTP/0.9 assume OK");
 	    $response = HTTP::Response->new(&HTTP::Status::RC_OK, "OK");
 	    $response->protocol('HTTP/0.9');
 	    last;
@@ -270,7 +258,6 @@ sub request
 	}
 	else {
 	    # need more data
-	    LWP::Debug::debug("need more status line data");
 	}
     };
     $response->request($request);
@@ -291,7 +278,6 @@ sub request
 	die "read timeout" if $timeout && !$sel->can_read($timeout);
 	my $n = $socket->sysread($buf, $size);
 	die $! unless defined($n);
-	#LWP::Debug::conns($buf);
 	return \$buf;
 	} );
 
